@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-08 14:02:33
-# @Last Modified time: 2020-06-17 21:08:54
+# @Last Modified time: 2020-10-22 16:24:00
 # @github: https://github.com/longfengpili
 
 #!/usr/bin/env python3
@@ -10,6 +10,7 @@
 from .redshift import RedshiftDB
 from .sqlite import SqliteDB
 from .mysql import MysqlDB
+from .snowflake import SnowflakeDB
 
 __doc__ = "数据库接口"
-__all__ = ['RedshiftDB', 'SqliteDB', 'MysqlDB']
+__all__ = ['RedshiftDB', 'SqliteDB', 'MysqlDB', 'SnowflakeDB']
