@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-03 15:25:44
-# @Last Modified time: 2020-07-02 18:15:44
+# @Last Modified time: 2020-12-02 14:52:18
 # @github: https://github.com/longfengpili
 
 #!/usr/bin/env python3
@@ -21,9 +21,10 @@ from pydbapi.conf import LOGGING_CONFIG
 logging.config.dictConfig(LOGGING_CONFIG)
 sqlitelogger = logging.getLogger('sqlite')
 
+
 class SqliteCompile(SqlCompile):
     '''[summary]
-    
+
     [description]
         构造redshift sql
     Extends:
@@ -42,17 +43,13 @@ class SqliteCompile(SqlCompile):
         #     sql = f"{sql.replace(';', '')}interleaved sortkey({indexes});"
         return sql
 
-    def add_columns(self, col_name, col_type):
-        sql = f'alter table {self.tablename} add column {col_name} {col_type} default null;'
-        return sql
-
 
 class SqliteDB(DBCommon, DBFileExec):
 
     def __init__(self, database=None):
         self.database = database
         super(SqliteDB, self).__init__()
-    
+
     def get_conn(self):
         if not self.database:
             self.database = os.path.join(LOG_BASE_PATH, 'sqlite3_test.db')
@@ -67,23 +64,3 @@ class SqliteDB(DBCommon, DBFileExec):
         sql_for_create = sqlcompile.create(columns, indexes)
         rows, action, result = self.execute(sql_for_create)
         return rows, action, result
-
-    def add_columns(self, tablename, columns):
-        old_columns = self.get_columns(tablename)
-        old_columns = set(old_columns)
-        new_columns = set(columns)
-        # sqlitelogger.info(f'{old_columns}, {new_columns}')
-
-        if old_columns == new_columns:
-            sqlitelogger.info(f'【{tablename}】columns not changed !')
-        if old_columns - new_columns:
-            raise Exception(f"【{tablename}】columns【{old_columns - new_columns}】 not set, should exists !")
-        if new_columns - old_columns:
-            sqlcompile = SqliteCompile(tablename)
-            add_columns = new_columns - old_columns
-            for col_name in add_columns:
-                col_type = columns.get(col_name)
-                sql = sqlcompile.add_columns(col_name, col_type)
-                self.execute(sql)
-            sqlitelogger.info(f'【{tablename}】add columns succeeded !【{new_columns - old_columns}】')
-
